.. image:: https://readthedocs.org/projects/robophisher/badge/?version=latest
    :target: http://robophisher.readthedocs.io/en/latest/?badge=latest

.. image:: https://travis-ci.org/blackHatMonkey/RoboPhisher.svg?branch=master
    :target: https://travis-ci.org/blackHatMonkey/RoboPhisher

.. image:: https://badge.fury.io/py/robophisher.svg
    :target: https://badge.fury.io/py/robophisher


RoboPhisher 
===========

What is it?
-----------

RoboPhisher is a security tool that mounts automated victim-customized
phishing attacks against WiFi clients in order to obtain credentials or
infect the victims with malware. It is primarily a social engineering
attack that unlike other methods it does not include any brute forcing.
It is an easy way for obtaining credentials from captive portals and third
party login pages (e.g. in social networks) or WPA/WPA2 passphrases.

The Latest Version
------------------

Details of the latest version can be found on the projects Github
page under https://github.com/blackHatMonkey/RoboPhisher.

Documentation
-------------

The documentation available as of the date of this release is
included in RST format in the docs/ directory. The most
up-to-date documentation can be found at
http://robophisher.readthedocs.io/en/latest/.

Installation
------------

Please see the Getting Started section of the documentation.

Licensing
---------

Please see the file called LICENSE.

Contacts
--------

* If you want to be informed about new code releases, bug fixes,
  security fixes, general news and information about RoboPhisher 
  subscribe to the Github project under
  <https://github.com/blackHatMonkey/RoboPhisher>

* If you have a concrete bug report for RoboPhisher please see
  the instructions for bug reporting at
  <http://robophisher.readthedocs.io/en/latest/users_guide.html#bug-reporting>

Disclaimer
----------

Usage of RoboPhisher for attacking infrastructures without prior mutual
agreement can be considered as an illegal activity. It is the final
user's responsibility to obey all applicable local, state and federal laws.
Authors assume no liability and are not responsible for any misuse or damage
caused by this program.
